@@ -1,7 +1,7 @@
 import click
 from clease_gui import __version__
 
-__all__ = ['clease_gui_cli']
+__all__ = ["clease_gui_cli"]
 
 
 @click.group()
